==> pandoc-crossref-0.2.5.0-73-armv7h.pkg.tar.xz: usr/share/haskell/register/pandoc-crossref.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pandoc-crossref
version: 0.2.5.0
id: pandoc-crossref-0.2.5.0-48uFbS8G9GY5hNla0qhvnp
key: pandoc-crossref-0.2.5.0-48uFbS8G9GY5hNla0qhvnp
license: GPL-2
maintainer: root@livid.pp.ru
synopsis: Pandoc filter for cross-references
description:
    pandoc-crossref is a pandoc filter for numbering figures, equations, tables and cross-references to them.
category: Text
author: Nikolay Yakimov
exposed: True
exposed-modules:
    Text.Pandoc.CrossRef
hidden-modules: Text.Pandoc.CrossRef.References
                Text.Pandoc.CrossRef.References.Blocks
                Text.Pandoc.CrossRef.References.List
                Text.Pandoc.CrossRef.References.Refs
                Text.Pandoc.CrossRef.References.Types
                Text.Pandoc.CrossRef.Util.Settings Text.Pandoc.CrossRef.Util.Meta
                Text.Pandoc.CrossRef.Util.Options
                Text.Pandoc.CrossRef.Util.Template Text.Pandoc.CrossRef.Util.Util
                Text.Pandoc.CrossRef.Util.CustomLabels
                Text.Pandoc.CrossRef.Util.CodeBlockCaptions
                Text.Pandoc.CrossRef.Util.ModifyMeta
                Text.Pandoc.CrossRef.Util.Settings.Gen
                Text.Pandoc.CrossRef.Util.Settings.Template
                Text.Pandoc.CrossRef.Util.Gap
                Text.Pandoc.CrossRef.Util.PandocOrphans
abi: 6fbfdd4a505956458e0b0087c23b4e68
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/pandoc-crossref-0.2.5.0
library-dirs: /usr/lib/ghc-8.0.2/site-local/pandoc-crossref-0.2.5.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/pandoc-crossref
hs-libraries: HSpandoc-crossref-0.2.5.0-48uFbS8G9GY5hNla0qhvnp
depends:
    base-4.9.1.0 containers-0.5.7.1
    data-accessor-0.2.2.7-EIyoGWJa6mi6QAVcUY9dHP
    data-accessor-template-0.2.1.13-8rNaC2Bvf4dHA5NUxIpbe1
    data-accessor-transformers-0.2.1.7-6YP6JqsIeFrBCN7cotgZiz
    data-default-0.7.1.1-BNa3MzH41nV77yjS9K2Umq directory-1.3.0.0
    filepath-1.4.1.1 mtl-2.2.1-BLKBelFsPB3BoFeSWSOYj6
    pandoc-1.19.2.1-IKk5Y7TTMe78qGNHx16S5x
    pandoc-types-1.17.0.5-2cxwQXpbmCI6RcJh1kZK1B
    roman-numerals-0.5.1.5-9qUga2nrSVO7Yt8FGsRq4F
    syb-0.6-IcoSwlPi2Nx4zSqMmorFPS template-haskell-2.11.1.0
    utility-ht-0.0.14-24xG04xbcZ3HPMjtp2taYT
haddock-interfaces: /usr/share/doc/pandoc-crossref/html/pandoc-crossref.haddock
haddock-html: /usr/share/doc/pandoc-crossref/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> pandoc-crossref-0.2.5.0-74-armv7h.pkg.tar.xz: usr/share/haskell/register/pandoc-crossref.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pandoc-crossref
version: 0.2.5.0
id: pandoc-crossref-0.2.5.0-CyRVX0JLxbaB3D3eRcBhvW
key: pandoc-crossref-0.2.5.0-CyRVX0JLxbaB3D3eRcBhvW
license: GPL-2
maintainer: root@livid.pp.ru
synopsis: Pandoc filter for cross-references
description:
    pandoc-crossref is a pandoc filter for numbering figures, equations, tables and cross-references to them.
category: Text
author: Nikolay Yakimov
exposed: True
exposed-modules:
    Text.Pandoc.CrossRef
hidden-modules: Text.Pandoc.CrossRef.References
                Text.Pandoc.CrossRef.References.Blocks
                Text.Pandoc.CrossRef.References.List
                Text.Pandoc.CrossRef.References.Refs
                Text.Pandoc.CrossRef.References.Types
                Text.Pandoc.CrossRef.Util.Settings Text.Pandoc.CrossRef.Util.Meta
                Text.Pandoc.CrossRef.Util.Options
                Text.Pandoc.CrossRef.Util.Template Text.Pandoc.CrossRef.Util.Util
                Text.Pandoc.CrossRef.Util.CustomLabels
                Text.Pandoc.CrossRef.Util.CodeBlockCaptions
                Text.Pandoc.CrossRef.Util.ModifyMeta
                Text.Pandoc.CrossRef.Util.Settings.Gen
                Text.Pandoc.CrossRef.Util.Settings.Template
                Text.Pandoc.CrossRef.Util.Gap
                Text.Pandoc.CrossRef.Util.PandocOrphans
abi: 2e8b171fae5da6453d03767827187bf5
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/pandoc-crossref-0.2.5.0
library-dirs: /usr/lib/ghc-8.0.2/site-local/pandoc-crossref-0.2.5.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/pandoc-crossref
hs-libraries: HSpandoc-crossref-0.2.5.0-CyRVX0JLxbaB3D3eRcBhvW
depends:
    base-4.9.1.0 containers-0.5.7.1
    data-accessor-0.2.2.7-EIyoGWJa6mi6QAVcUY9dHP
    data-accessor-template-0.2.1.13-8rNaC2Bvf4dHA5NUxIpbe1
    data-accessor-transformers-0.2.1.7-6YP6JqsIeFrBCN7cotgZiz
    data-default-0.7.1.1-BNa3MzH41nV77yjS9K2Umq directory-1.3.0.0
    filepath-1.4.1.1 mtl-2.2.1-BLKBelFsPB3BoFeSWSOYj6
    pandoc-1.19.2.1-Ba9exZ1FKYz3kpkZK92Ff3
    pandoc-types-1.17.0.5-2cxwQXpbmCI6RcJh1kZK1B
    roman-numerals-0.5.1.5-9qUga2nrSVO7Yt8FGsRq4F
    syb-0.6-IcoSwlPi2Nx4zSqMmorFPS template-haskell-2.11.1.0
    utility-ht-0.0.14-24xG04xbcZ3HPMjtp2taYT
haddock-interfaces: /usr/share/doc/pandoc-crossref/html/pandoc-crossref.haddock
haddock-html: /usr/share/doc/pandoc-crossref/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
